# arpes package

## Subpackages

  -   - [arpes.analysis package](arpes.analysis)
        
          -   - [Submodules](arpes.analysis#submodules)
                
                  - [arpes.analysis.band\_analysis
                    module](arpes.analysis.band_analysis)
                  - [arpes.analysis.band\_analysis\_utils
                    module](arpes.analysis.band_analysis_utils)
                  - [arpes.analysis.decomposition
                    module](arpes.analysis.decomposition)
                  - [arpes.analysis.deconvolution
                    module](arpes.analysis.deconvolution)
                  - [arpes.analysis.derivative
                    module](arpes.analysis.derivative)
                  - [arpes.analysis.fft module](arpes.analysis.fft)
                  - [arpes.analysis.filters
                    module](arpes.analysis.filters)
                  - [arpes.analysis.fs module](arpes.analysis.fs)
                  - [arpes.analysis.gap module](arpes.analysis.gap)
                  - [arpes.analysis.general
                    module](arpes.analysis.general)
                  - [arpes.analysis.kfermi
                    module](arpes.analysis.kfermi)
                  - [arpes.analysis.mask module](arpes.analysis.mask)
                  - [arpes.analysis.path module](arpes.analysis.path)
                  - [arpes.analysis.pocket
                    module](arpes.analysis.pocket)
                  - [arpes.analysis.resolution
                    module](arpes.analysis.resolution)
                  - [arpes.analysis.sarpes
                    module](arpes.analysis.sarpes)
                  - [arpes.analysis.savitzky\_golay
                    module](arpes.analysis.savitzky_golay)
                  - [arpes.analysis.shirley
                    module](arpes.analysis.shirley)
                  - [arpes.analysis.statistics
                    module](arpes.analysis.statistics)
                  - [arpes.analysis.tarpes
                    module](arpes.analysis.tarpes)
                  - [arpes.analysis.xps module](arpes.analysis.xps)
        
          - [Module contents](arpes.analysis#module-arpes.analysis)

  -   - [arpes.corrections package](arpes.corrections)
        
          -   - [Submodules](arpes.corrections#submodules)
                
                  - [arpes.corrections.background
                    module](arpes.corrections.background)
                  - [arpes.corrections.cycle
                    module](arpes.corrections.cycle)
                  - [arpes.corrections.fermi\_edge\_corrections
                    module](arpes.corrections.fermi_edge_corrections)
        
          - [Module
            contents](arpes.corrections#module-arpes.corrections)

  -   - [arpes.endstations package](arpes.endstations)
        
          -   - [Subpackages](arpes.endstations#subpackages)
                
                  -   - [arpes.endstations.plugin
                        package](arpes.endstations.plugin)
                        
                          -   - [Submodules](arpes.endstations.plugin#submodules)
                                
                                  - [arpes.endstations.plugin.ALG\_main
                                    module](arpes.endstations.plugin.ALG_main)
                                  - [arpes.endstations.plugin.ALG\_spin\_ToF
                                    module](arpes.endstations.plugin.ALG_spin_ToF)
                                  - [arpes.endstations.plugin.ANTARES
                                    module](arpes.endstations.plugin.ANTARES)
                                  - [arpes.endstations.plugin.HERS
                                    module](arpes.endstations.plugin.HERS)
                                  - [arpes.endstations.plugin.MAESTRO
                                    module](arpes.endstations.plugin.MAESTRO)
                                  - [arpes.endstations.plugin.MBS
                                    module](arpes.endstations.plugin.MBS)
                                  - [arpes.endstations.plugin.SToF\_DLD
                                    module](arpes.endstations.plugin.SToF_DLD)
                                  - [arpes.endstations.plugin.igor\_export
                                    module](arpes.endstations.plugin.igor_export)
                                  - [arpes.endstations.plugin.kaindl
                                    module](arpes.endstations.plugin.kaindl)
                                  - [arpes.endstations.plugin.merlin
                                    module](arpes.endstations.plugin.merlin)
                        
                          - [Module
                            contents](arpes.endstations.plugin#module-arpes.endstations.plugin)
        
          -   - [Submodules](arpes.endstations#submodules)
                
                  - [arpes.endstations.fits\_utils
                    module](arpes.endstations.fits_utils)
                  - [arpes.endstations.igor\_utils
                    module](arpes.endstations.igor_utils)
                  - [arpes.endstations.nexus\_utils
                    module](arpes.endstations.nexus_utils)
        
          - [Module
            contents](arpes.endstations#module-arpes.endstations)

  -   - [arpes.fits package](arpes.fits)
        
          -   - [Submodules](arpes.fits#submodules)
                
                  - [arpes.fits.fit\_models
                    module](arpes.fits.fit_models)
                  - [arpes.fits.lmfit\_html\_repr
                    module](arpes.fits.lmfit_html_repr)
                  - [arpes.fits.lmfit\_plot
                    module](arpes.fits.lmfit_plot)
                  - [arpes.fits.utilities module](arpes.fits.utilities)
        
          - [Module contents](arpes.fits#module-arpes.fits)

  -   - [arpes.laue package](arpes.laue)
        
          - [Module contents](arpes.laue#module-arpes.laue)

  -   - [arpes.models package](arpes.models)
        
          -   - [Submodules](arpes.models#submodules)
                
                  - [arpes.models.band module](arpes.models.band)
        
          - [Module contents](arpes.models#module-arpes.models)

  -   - [arpes.plotting package](arpes.plotting)
        
          -   - [Subpackages](arpes.plotting#subpackages)
                
                  -   - [arpes.plotting.qt\_tool
                        package](arpes.plotting.qt_tool)
                        
                          -   - [Submodules](arpes.plotting.qt_tool#submodules)
                                
                                  - [arpes.plotting.qt\_tool.AxisInfoWidget
                                    module](arpes.plotting.qt_tool.AxisInfoWidget)
                                  - [arpes.plotting.qt\_tool.BinningInfoWidget
                                    module](arpes.plotting.qt_tool.BinningInfoWidget)
                                  - [arpes.plotting.qt\_tool.DataArrayImageView
                                    module](arpes.plotting.qt_tool.DataArrayImageView)
                                  - [arpes.plotting.qt\_tool.HelpDialog
                                    module](arpes.plotting.qt_tool.HelpDialog)
                                  - [arpes.plotting.qt\_tool.utils
                                    module](arpes.plotting.qt_tool.utils)
                        
                          - [Module
                            contents](arpes.plotting.qt_tool#module-arpes.plotting.qt_tool)
        
          -   - [Submodules](arpes.plotting#submodules)
                
                  - [arpes.plotting.annotations
                    module](arpes.plotting.annotations)
                  - [arpes.plotting.band\_tool
                    module](arpes.plotting.band_tool)
                  - [arpes.plotting.bands module](arpes.plotting.bands)
                  - [arpes.plotting.basic module](arpes.plotting.basic)
                  - [arpes.plotting.bz module](arpes.plotting.bz)
                  - [arpes.plotting.comparison\_tool
                    module](arpes.plotting.comparison_tool)
                  - [arpes.plotting.curvature\_tool
                    module](arpes.plotting.curvature_tool)
                  - [arpes.plotting.dispersion
                    module](arpes.plotting.dispersion)
                  - [arpes.plotting.dos module](arpes.plotting.dos)
                  - [arpes.plotting.dyn\_tool
                    module](arpes.plotting.dyn_tool)
                  - [arpes.plotting.false\_color
                    module](arpes.plotting.false_color)
                  - [arpes.plotting.fermi\_edge
                    module](arpes.plotting.fermi_edge)
                  - [arpes.plotting.fermi\_surface
                    module](arpes.plotting.fermi_surface)
                  - [arpes.plotting.fit\_inspection\_tool
                    module](arpes.plotting.fit_inspection_tool)
                  - [arpes.plotting.interactive
                    module](arpes.plotting.interactive)
                  - [arpes.plotting.interactive\_utils
                    module](arpes.plotting.interactive_utils)
                  - [arpes.plotting.mask\_tool
                    module](arpes.plotting.mask_tool)
                  - [arpes.plotting.movie module](arpes.plotting.movie)
                  - [arpes.plotting.parameter
                    module](arpes.plotting.parameter)
                  - [arpes.plotting.path\_tool
                    module](arpes.plotting.path_tool)
                  - [arpes.plotting.spatial
                    module](arpes.plotting.spatial)
                  - [arpes.plotting.spin module](arpes.plotting.spin)
                  - [arpes.plotting.stack\_plot
                    module](arpes.plotting.stack_plot)
                  - [arpes.plotting.tarpes
                    module](arpes.plotting.tarpes)
                  - [arpes.plotting.tof module](arpes.plotting.tof)
                  - [arpes.plotting.utils module](arpes.plotting.utils)
                  - [arpes.plotting.visualize\_3d
                    module](arpes.plotting.visualize_3d)
        
          - [Module contents](arpes.plotting#module-arpes.plotting)

  -   - [arpes.preparation package](arpes.preparation)
        
          -   - [Submodules](arpes.preparation#submodules)
                
                  - [arpes.preparation.axis\_preparation
                    module](arpes.preparation.axis_preparation)
                  - [arpes.preparation.coord\_preparation
                    module](arpes.preparation.coord_preparation)
                  - [arpes.preparation.hemisphere\_preparation
                    module](arpes.preparation.hemisphere_preparation)
                  - [arpes.preparation.tof\_preparation
                    module](arpes.preparation.tof_preparation)
        
          - [Module
            contents](arpes.preparation#module-arpes.preparation)

  -   - [arpes.utilities package](arpes.utilities)
        
          -   - [Subpackages](arpes.utilities#subpackages)
                
                  -   - [arpes.utilities.conversion
                        package](arpes.utilities.conversion)
                        
                          -   - [Submodules](arpes.utilities.conversion#submodules)
                                
                                  - [arpes.utilities.conversion.base
                                    module](arpes.utilities.conversion.base)
                                  - [arpes.utilities.conversion.bounds\_calculations
                                    module](arpes.utilities.conversion.bounds_calculations)
                                  - [arpes.utilities.conversion.core
                                    module](arpes.utilities.conversion.core)
                                  - [arpes.utilities.conversion.forward
                                    module](arpes.utilities.conversion.forward)
                                  - [arpes.utilities.conversion.kx\_ky\_conversion
                                    module](arpes.utilities.conversion.kx_ky_conversion)
                                  - [arpes.utilities.conversion.kz\_conversion
                                    module](arpes.utilities.conversion.kz_conversion)
                                  - [arpes.utilities.conversion.remap\_manipulator
                                    module](arpes.utilities.conversion.remap_manipulator)
                                  - [arpes.utilities.conversion.tof
                                    module](arpes.utilities.conversion.tof)
                        
                          - [Module
                            contents](arpes.utilities.conversion#module-arpes.utilities.conversion)
        
          -   - [Submodules](arpes.utilities#submodules)
                
                  - [arpes.utilities.attrs
                    module](arpes.utilities.attrs)
                  - [arpes.utilities.autoprep
                    module](arpes.utilities.autoprep)
                  - [arpes.utilities.bz module](arpes.utilities.bz)
                  - [arpes.utilities.collections
                    module](arpes.utilities.collections)
                  - [arpes.utilities.dataset
                    module](arpes.utilities.dataset)
                  - [arpes.utilities.dict module](arpes.utilities.dict)
                  - [arpes.utilities.funcutils
                    module](arpes.utilities.funcutils)
                  - [arpes.utilities.geometry
                    module](arpes.utilities.geometry)
                  - [arpes.utilities.jupyter\_utils
                    module](arpes.utilities.jupyter_utils)
                  - [arpes.utilities.math module](arpes.utilities.math)
                  - [arpes.utilities.normalize
                    module](arpes.utilities.normalize)
                  - [arpes.utilities.region
                    module](arpes.utilities.region)
                  - [arpes.utilities.string
                    module](arpes.utilities.string)
                  - [arpes.utilities.xarray
                    module](arpes.utilities.xarray)
        
          - [Module contents](arpes.utilities#module-arpes.utilities)

## Submodules

  - [arpes.bootstrap module](arpes.bootstrap)
  - [arpes.config module](arpes.config)
  - [arpes.constants module](arpes.constants)
  - [arpes.exceptions module](arpes.exceptions)
  - [arpes.experiment module](arpes.experiment)
  - [arpes.io module](arpes.io)
  - [arpes.laser module](arpes.laser)
  - [arpes.load\_pxt module](arpes.load_pxt)
  - [arpes.optics module](arpes.optics)
  - [arpes.pipeline module](arpes.pipeline)
  - [arpes.pipelines module](arpes.pipelines)
  - [arpes.provenance module](arpes.provenance)
  - [arpes.repair module](arpes.repair)
  - [arpes.simulation module](arpes.simulation)
  - [arpes.typing module](arpes.typing)
  - [arpes.widgets module](arpes.widgets)
  - [arpes.xarray\_extensions module](arpes.xarray_extensions)
  - [arpes.xarray\_html\_repr module](arpes.xarray_html_repr)

## Module contents

**arpes.check()**

> Verifies certain aspects of the installation and provides guidance for
> semi-broken installations. :return:

**arpes.setup(outer\_globals, arpes\_root=None)**

> Performs standard imports similar to what might be achieved by
> specifying a reasonable IPython startup file.
> 
> Consider this a “basic” configuration function for those that do not
> want to deal with IPython configuration themselves.
> 
> As a bonus, this file tracks with the repository so that function
> moves should happen fairly transparently, and new functionality
> becomes “automatically” available.
> 
>   - Parameters
>     
>       -   - **outer\_globals** – Globals for the calling module
>             scope,  
>             this should be provided by calling setup(globals(), …)
>     
>       -   - **arpes\_root** – Location of the analysis directory you
>             are  
>             working in, as generated by
> 
>   - Returns
